image create photo NeXTarrowR -data {
R0lGODlhCAAJAKEAAAAAALLA3HNzc////yH5BAEAAAEALAAAAAAIAAkAAAIUVI4BYgnH0ENx
pmHDGOps+V0JUgAAOw==
}

proc binder_readIconSet {} {
	global ttblibPath GLPath

	set oldDir [pwd]

	cd $ttblibPath/icons

	foreach j [glob *.gif] {
		if {[winfo exists [file rootname $j]]} {
			image delete [file rootname $j]
		}

		image create photo [file rootname $j] -file $j
	}

	if {[file exists $GLPath/Icons]} {
		if {[catch "glob $GLPath/Icons/*.gif"]!=0} {
			cd $oldDir
			return
		}

		cd $GLPath/Icons

		foreach j [glob *.gif] {
			if {[winfo exists [file rootname $j]]} {
				image delete [file rootname $j]
			}

			image create photo [file rootname $j] -file $j
		}
	}

	cd $oldDir

}

