#!/usr/bin/perl

foreach $file (@ARGV) {
	print ("Processing: ".$file);
	system ("/usr/X11/pbmplus/giftopnm ".$file." > temp.pnm") ;
	system ("/usr/X11/pbmplus/ppmtogif -transparent \\$color temp.pnm > ".$file) ;
	print ("...done.\n") ;
}
