#!/bin/sh

echo "The install.sh is installing the Binder's files."
echo ""
echo "Installing files..."
echo `ln -sf /usr/local/JDE/Binder/bin/Binder.app /usr/local/bin`
echo `ln -sf /usr/local/JDE/Binder/bin/Processes.app /usr/local/bin`

echo "Done."
