##########################################################################
#
# version check
#
#

proc TkStep_check_dummy {dummy} {
}

proc TkStep_check {} {
	if {[catch {bind . <Drop> "TkStep_check_dummy %D"}]!=0} {
		message .m -text "\t\tError.\nThis version of Tcl/Tk don't have the \nDrag and Drop extension which style is\nOffix.\n\nPlease install the TkStep first.\n\nYou can download it from\n\nhttp://www.aaa-int.or.jp/~jfactory/softlabo/TkStep/"

		.m configure -width 320
		pack .m

		bind . <Any-ButtonRelease> exit
		tkwait window .
	}

	return
}

