proc binder_appIconInfo name {

	global GLPath

	set name [file tail $name]

	if [file exists $GLPath/appInfo] {
		set ttbapps [open $GLPath/appInfo r]
		set line [split [gets $ttbapps] \;]

		while {![eof $ttbapps]} {
			if {$name==[lindex $line 0]} {
				return [lindex $line 1]
			} else {
			}

		        set line [split [gets $ttbapps] \;]
		}
		close $ttbapps
		return CPUChip
	}
}

