set list {Bunny.gif CPUChip.gif DVI.gif FileAPP.gif FileAu.gif FileBlank.gif \
FileDotC.gif FileDotH.gif FileEPS.gif FileGz.gif FileHqx.gif FileLzh.gif \
FilePS.gif FileShar.gif FileSit.gif FileSnd.gif FileTar.gif FileTaz.gif \
FileTgz.gif FileURL.gif FileUnknown.gif FileZ.gif FileZip.gif FileZoo.gif \
FilesLink.gif Fonts2D.gif ImageGIF.gif ImageJPG.gif ImagePBM.gif \
ImagePGM.gif ImagePNM.gif ImagePPM.gif ImageTIFF.gif ImageXBM.gif \
ImageXPM.gif Java.gif MovieTestPattern.gif OpenSesame.gif PGP.gif \
TeXInfo.gif Webster.gif Wrench.gif netscape.gif}

foreach i $list {
	exec cp -f ../File.gif ./$i
}
