bind Listbox <2> {
	tkListboxBeginSelect %W [%W index @%x,%y]
}

bind Listbox <B2-Motion> {
    set tkPriv(x) %x
    set tkPriv(y) %y
    tkListboxMotion %W [%W index @%x,%y]
}

bind Listbox <ButtonRelease-2> {
    tkCancelRepeat
    %W activate @%x,%y
}

bind Listbox <Shift-2> {
    tkListboxBeginExtend %W [%W index @%x,%y]
}

bind Listbox <Control-2> {
    tkListboxBeginToggle %W [%W index @%x,%y]
}

bind Listbox <B2-Leave> {
    set tkPriv(x) %x
    set tkPriv(y) %y
    tkListboxAutoScan %W
}

bind Listbox <B2-Enter> {
    tkCancelRepeat
}
