proc binder_showItems {c select i j temp text icon mode} {
	global panelColor stageColor stageWidth stageHeight
	global frameWidth frameHeight itemWidth itemHeight binder_title
	global stageText

	set hitemWidth [expr $itemWidth/2];set hitemHeight [expr $itemHeight/2]

	set geomX [expr $j*$itemWidth];set geomY [expr $i*$itemHeight]

	if {$mode=="arrowEnable"} {
		set geomX [expr $geomX+8*$j] 
		$c create image \
			[expr $geomX-4] [expr $geomY+36] -image NeXTarrowR
	}

	set geomXX [expr $geomX+$hitemWidth]
	set geomYY [expr $geomY+$hitemHeight]
	set geomXXX [expr $geomXX+$itemWidth]
	set geomYYY [expr $geomYY+$itemHeight]

	$c create image $geomXX [expr $geomYY] \
		-image $icon -tags img$select$temp

	$c create text $geomXX [expr $geomYY+30] \
		-width $itemWidth -justify center \
		-text $text -tags txt$select$temp \
		-fill $stageText

	return $select$temp
}

